@@ -196,7 +196,7 @@ def ScaleConverter(dado, pixel_max,pixel_min,max_real, min_real=0):
 
     return min_real + ((dado-pixel_min)/(pixel_max-pixel_min)) * (max_real-min_real)
 
-def MotionMetrics (data, bodyPart, filter=0,  fps=30):
+def MotionMetrics (data, bodyPart, filter=0, fps=30, max_real = 60, min_real = 0):
     """
     Performs motion-related metrics such as velocity, acceleration, and distance.
 
@@ -210,7 +210,11 @@ def MotionMetrics (data, bodyPart, filter=0,  fps=30):
         Threshold to remove motion artifacts.   
     fps : int
         The recording frames per second.
-
+    max_real : int
+        Box maxixum value (eg., box wall).
+    min_real : int
+        Box maxixum value, usually zero.
+        
     Returns
     -------
     out : pandas DataFrame
@@ -231,8 +235,8 @@ def MotionMetrics (data, bodyPart, filter=0,  fps=30):
     dataX = values[:,lista1.index(bodyPart+" - x")]
     dataY = values[:,lista1.index(bodyPart+" - y")]
 
-    dataX = scaleConverter(dataX,dataX.max(),dataX.min(), 60,0)
-    dataY = scaleConverter(dataY,dataY.max(),dataY.min(), 60,0)
+    dataX = ScaleConverter(dataX,dataX.max(),dataX.min(), max_real,0)
+    dataY = ScaleConverter(dataY,dataY.max(),dataY.min(), min_real,0)
 
     time = np.arange(0,((1/fps)*len(dataX)), (1/fps))
     df = pd.DataFrame(time, columns = ["Time"])
